{{ "{:<15} {:<25} {:<25} {:<32} {:<25}".format("NAME", "CREATED", "EXPIRES", "VERSION", "VAULT") }}
{%- for secret in secrets %}
{{ secret.name.ljust(15) }} {{ secret.created_on.ljust(25) }} {{ secret.expires_on.ljust(25) }} {{ secret.version.ljust(32) }} {{ secret.vault_name.ljust(25) }}
{%- endfor %}
